/************************************************************************/
/*																		*/
/*	LED.cpp		--		Definition for LED library 	  			  		*/
/*																		*/
/************************************************************************/
/*	Author:		Eric Marsh												*/
/*	Copyright 2016, Digilent Inc.										*/
/************************************************************************/
/*  File Description:													*/
/*		This file defines functions for the PmodLED						*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/*																		*/
/*	07/21/2016(EricM): created											*/
/*																		*/
/************************************************************************/


/* ------------------------------------------------------------ */
/*				Include File Definitions						*/
/* ------------------------------------------------------------ */
#include "LED.h"
#include <WProgram.h>


/* ------------------------------------------------------------ */
/*				Procedure Definitions							*/
/* ------------------------------------------------------------ */


/* ------------------------------------------------------------ */
/*        LED::LED
**
**        Synopsis:
**				
**        Parameters:
**
**
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**			Class constructor. Performs variables initialization tasks
**
**
*/
LED::LED()
{
	LD0 = -1;
	LD1 = -1;
	LD2 = -1;
	LD3 = -1;
}

/* ------------------------------------------------------------ */
/*        LED::begin
**
**        Synopsis:
**				LED.begin(0, 1, 2, 3, 300);
**        Parameters:
**				int LED0 - pin # for LD0
**				int LED1 - pin # for LD1
**				int LED2 - pin # for LD2
**				int LED3 - pin # for LD3
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**				This function initializes the LED pins to utilize PmodLED
**
**
*/
void LED::begin(int LED0, int LED1, int LED2, int LED3)
{
	LD0 = LED0;
	LD1 = LED1;
	LD2 = LED2;
	LD3 = LED3;
	
	pinMode(LD0, OUTPUT);
	pinMode(LD1, OUTPUT);
	pinMode(LD2, OUTPUT);
	pinMode(LD3, OUTPUT);
	
	digitalWrite(LD0, LOW); 
	digitalWrite(LD1, LOW); 
	digitalWrite(LD2, LOW); 
	digitalWrite(LD3, LOW); 
}

/* ------------------------------------------------------------ */
/*        LED::GetLED
**
**        Synopsis:
**				LED.GetLED(0);
**        Parameters:
**				- int LED - the # of LED to return the pin of.
**        Return Values:
**                int - the pin # assigned to the LED
**
**        Errors:
**
**
**        Description:
**				Accepts a int between 0 and 3, and returns the pin # of the LED associated with that int.
**
**
*/
int LED::GetLED(int LED)
{
	if( LED > 3 || LED < 0 || LD0 == -1){
		return -1;
	}
	switch(LED){
		case 0:
			return LD0;
		case 1:
			return LD1;
		case 2:
			return LD2;
		case 3:
			return LD3;
		default:
			return -1;
	}
}

/* ------------------------------------------------------------ */
/*        LED::Blink
**
**        Synopsis:
**				LED.Blink(0);
**        Parameters:
**				- int LED - the LED on PmodLED to light up (0-3)
**				- int waitTime - time to wait inbetween blinks (100 by default)
**        Return Values:
**                bool - If function was sucessful 
**
**        Errors:
**
**
**        Description:
**				Turns on LED, waits the predefined wait period, and turns it off.
**
**
*/
bool LED::Blink(int LED, int waitTime)
{
	int LD = GetLED(LED);
	if( LD == -1){
		return false;
	}
	digitalWrite(LD, HIGH); 
	delay(waitTime);                  
	digitalWrite(LD, LOW);    
	return true;
}

/* ------------------------------------------------------------ */
/*        LED::TurnOn
**
**        Synopsis:
**				LED.TurnOn(0);
**        Parameters:
**				- int LED - the LED on PmodLED to light up (0-3)
**        Return Values:
**                bool - If function was sucessful 
**
**        Errors:
**
**
**        Description:
**				Turns on LED
**
**
*/
bool LED::TurnOn(int LED)
{
	int LD = GetLED(LED);
	if( LD == -1){
		return false;
	}
	digitalWrite(LD0 + LED, HIGH); 
	return true;
}

/* ------------------------------------------------------------ */
/*        LED::TurnOff
**
**        Synopsis:
**				LED.TurnOff(0);
**        Parameters:
**				- int LED - the LED on PmodLED to light up (0-3)
**        Return Values:
**                bool - If function was sucessful 
**
**        Errors:
**
**
**        Description:
**				Turns off LED
**
**
*/
bool LED::TurnOff(int LED)
{
	int LD = GetLED(LED);
	if( LD == -1){
		return false;
	}
	digitalWrite(LD0 + LED, LOW); 
	return true;
}

/* ------------------------------------------------------------ */
/*        LED::TurnAllOn
**
**        Synopsis:
**				LED.TurnAllOn();
**        Parameters:
**
**        Return Values:
**                bool - If function was sucessful 
**
**        Errors:
**
**
**        Description:
**				Turns on all LEDs
**
**
*/
bool LED::TurnAllOn()
{
	int LD;
	for(int i = 0; i < 4; i++){
		LD = GetLED(i);
		if(LD != -1){
			digitalWrite(LD, HIGH);
		} else {
			return false;
		}
	}
	return true;
}

/* ------------------------------------------------------------ */
/*        LED::TurnAllOff
**
**        Synopsis:
**				LED.TurnAllOff();
**        Parameters:
**
**        Return Values:
**                bool - If function was sucessful 
**
**        Errors:
**
**
**        Description:
**				Turns off all LEDs
**
**
*/
bool LED::TurnAllOff()
{
	int LD;
	for(int i = 0; i < 4; i++){
		LD = GetLED(i);
		if(LD != -1){
			digitalWrite(LD, LOW);
		} else {
			return false;
		}
	}
	return true;
}